@@ -1,3 +1,4 @@
+import process_pose_data.viz_3d
 import honeycomb_io
 import pandas as pd
 import numpy as np
@@ -186,6 +187,41 @@ def fetch_2d_pose_data_alphapose_local_time_segment(
         carryover_poses.sort_values(['timestamp', 'assignment_id'], inplace=True)
     return current_poses, carryover_poses
 
+def fetch_3d_poses_with_person_info_json(
+    base_dir,
+    environment_id,
+    pose_track_3d_identification_inference_id,
+    start=None,
+    end=None,
+    pose_processing_subdirectory='pose_processing',
+    output_path=None,
+    client=None,
+    uri=None,
+    token_uri=None,
+    audience=None,
+    client_id=None,
+    client_secret=None
+):
+    poses_3d_with_person_info_df = fetch_3d_poses_with_person_info(
+        base_dir=base_dir,
+        environment_id=environment_id,
+        pose_track_3d_identification_inference_id=pose_track_3d_identification_inference_id,
+        start=start,
+        end=end,
+        pose_processing_subdirectory=pose_processing_subdirectory,
+        client=client,
+        uri=uri,
+        token_uri=token_uri,
+        audience=audience,
+        client_id=client_id,
+        client_secret=client_secret
+    )
+    poses_3d_with_person_info_json = process_pose_data.viz_3d.convert_3d_poses_with_person_info_to_json(
+        poses_3d_with_person_info_df=poses_3d_with_person_info_df,
+        output_path=output_path
+    )
+    return poses_3d_with_person_info_json
+
 def fetch_3d_poses_with_person_info(
     base_dir,
     environment_id,
@@ -405,6 +441,213 @@ def fetch_3d_poses_with_tracks_local(
     )
     return poses_3d_with_tracks_df
 
+def fetch_person_positions_local_json(
+    base_dir,
+    environment_id,
+    start,
+    end,
+    download_position_data_inference_id,
+    output_path=None,
+    pose_processing_subdirectory='pose_processing'
+):
+    person_positions = fetch_person_positions_local(
+        base_dir=base_dir,
+        environment_id=environment_id,
+        start=start,
+        end=end,
+        download_position_data_inference_id=download_position_data_inference_id,
+        pose_processing_subdirectory=pose_processing_subdirectory
+    )
+    person_positions_json = process_pose_data.viz_3d.convert_person_positions_to_json(
+        person_positions=person_positions,
+        output_path=output_path
+    )
+    return person_positions_json
+
+def fetch_person_positions_local(
+    base_dir,
+    environment_id,
+    start,
+    end,
+    download_position_data_inference_id,
+    pose_processing_subdirectory='pose_processing'
+):
+    person_positions = process_pose_data.fetch_data_local_by_time_segment(
+        start=start,
+        end=end,
+        base_dir=base_dir,
+        pipeline_stage='download_position_data',
+        environment_id=environment_id,
+        filename_stem='position_data',
+        inference_ids=download_position_data_inference_id,
+        data_ids=None,
+        sort_field=None,
+        object_type='dataframe',
+        pose_processing_subdirectory='pose_processing'
+    )
+    if len(person_positions) == 0:
+        return person_positions
+    person_ids = person_positions['person_id'].unique().tolist()
+    person_info = honeycomb_io.fetch_persons(
+        person_ids=person_ids,
+        person_types=None,
+        names=None,
+        first_names=None,
+        last_names=None,
+        nicknames=None,
+        short_names=None,
+        environment_id=None,
+        environment_name=None,
+        start=None,
+        end=None,
+        output_format='dataframe'
+    )
+    person_positions = person_positions.join(
+        person_info,
+        how='left',
+        on='person_id'
+    )
+    person_positions.sort_values(
+        'timestamp',
+        inplace=True,
+        ignore_index=True
+    )
+    person_positions['transparent_classroom_id'] = pd.to_numeric(person_positions['transparent_classroom_id']).astype('Int64')
+    person_positions['sensor_coordinates'] = person_positions.apply(
+        lambda row: np.asarray([row['x_position'], row['y_position'], row['z_position']]),
+        axis=1
+    )
+    person_positions = person_positions.reindex(columns=[
+        'timestamp',
+        'person_id',
+        'sensor_coordinates',
+        'person_type',
+        'name',
+        'first_name',
+        'last_name',
+        'nickname',
+        'short_name',
+        'transparent_classroom_id'
+    ])
+    person_positions.sort_values(
+        'timestamp',
+        inplace=True,
+        ignore_index=True
+    )
+    return person_positions
+
+def fetch_tray_positions_local_json(
+    base_dir,
+    environment_id,
+    start,
+    end,
+    download_position_data_trays_inference_id,
+    output_path=None,
+    pose_processing_subdirectory='pose_processing'
+):
+    tray_positions = fetch_tray_positions_local(
+        base_dir=base_dir,
+        environment_id=environment_id,
+        start=start,
+        end=end,
+        download_position_data_trays_inference_id=download_position_data_trays_inference_id,
+        pose_processing_subdirectory=pose_processing_subdirectory
+    )
+    tray_positions_json = process_pose_data.viz_3d.convert_tray_positions_to_json(
+        tray_positions=tray_positions,
+        output_path=output_path
+    )
+    return tray_positions_json
+
+def fetch_tray_positions_local(
+    base_dir,
+    environment_id,
+    start,
+    end,
+    download_position_data_trays_inference_id,
+    pose_processing_subdirectory='pose_processing'
+):
+    tray_positions = process_pose_data.fetch_data_local_by_time_segment(
+        start=start,
+        end=end,
+        base_dir=base_dir,
+        pipeline_stage='download_position_data_trays',
+        environment_id=environment_id,
+        filename_stem='position_data_trays',
+        inference_ids=download_position_data_trays_inference_id,
+        data_ids=None,
+        sort_field=None,
+        object_type='dataframe',
+        pose_processing_subdirectory='pose_processing'
+    )
+    if len(tray_positions) == 0:
+        return tray_positions
+    tray_ids = tray_positions['tray_id'].unique().tolist()
+    tray_info = honeycomb_io.fetch_trays(
+        tray_ids=tray_ids,
+        part_numbers=None,
+        serial_numbers=None,
+        names=None,
+        environment_id=None,
+        environment_name=None,
+        start=None,
+        end=None,
+        output_format='dataframe'
+    )
+    tray_positions = tray_positions.join(
+        tray_info,
+        how='left',
+        on='tray_id'
+    )
+    material_ids = tray_positions['material_id'].unique().tolist()
+    material_info = honeycomb_io.fetch_materials(
+        material_ids=material_ids,
+        names=None,
+        transparent_classroom_ids=None,
+        environment_id=None,
+        environment_name=None,
+        start=None,
+        end=None,
+        output_format='dataframe',
+        chunk_size=100,
+        client=None,
+        uri=None,
+        token_uri=None,
+        audience=None,
+        client_id=None,
+        client_secret=None
+    )
+    tray_positions = tray_positions.join(
+        material_info,
+        how='left',
+        on='material_id'
+    )
+    # tray_positions['transparent_classroom_id'] = pd.to_numeric(tray_positions['transparent_classroom_id']).astype('Int64')
+    tray_positions['sensor_coordinates'] = tray_positions.apply(
+        lambda row: np.asarray([row['x_position'], row['y_position'], row['z_position']]),
+        axis=1
+    )
+    tray_positions = tray_positions.reindex(columns=[
+        'timestamp',
+        'tray_id',
+        'material_id',
+        'sensor_coordinates',
+        'tray_name',
+        'tray_part_number',
+        'tray_serial_number',
+        'tray_name',
+        'material_name',
+        'material_transparent_classroom_id',
+        'material_transparent_classroom_type',
+        'material_description'
+    ])
+    tray_positions.sort_values(
+        'timestamp',
+        inplace=True,
+        ignore_index=True
+    )
+    return tray_positions
+
 def write_data_local_by_time_segment(
     data_object,
     base_dir,
@@ -689,10 +932,9 @@ def convert_pose_tracks_3d_to_df(
     return pose_3d_ids_with_tracks_df
 
 def add_short_track_labels(
-    poses_3d_with_tracks_df,
-    pose_track_3d_id_column_name='pose_track_3d_id'
+    poses_3d_with_tracks_df
 ):
-    pose_track_3d_id_index = poses_3d_with_tracks_df.groupby(pose_track_3d_id_column_name).apply(lambda x: x['timestamp'].min()).sort_values().index
+    pose_track_3d_id_index = poses_3d_with_tracks_df.groupby('pose_track_3d_id').apply(lambda x: x['timestamp'].min()).sort_values().index
     track_label_lookup = pd.DataFrame(
         range(1, len(pose_track_3d_id_index)+1),
         columns=['pose_track_3d_id_short'],
